@@ -36,7 +36,7 @@ residuals.tidyfit.models <- function(object, ...) {
   out <- object %>%
     dplyr::select(-dplyr::any_of(sel_cols)) %>%
     dplyr::mutate(residual = purrr::map(.data$model_object, ~.$resid())) %>%
-    dplyr::select(-.data$model_object) %>%
+    dplyr::select(- "model_object") %>%
     tidyr::unnest(.data$residual)
 
   col_ord <- c(gr_vars, "model", "grid_id", "slice_id", "class", "residual")
@@ -48,9 +48,9 @@ residuals.tidyfit.models <- function(object, ...) {
     dplyr::mutate(nids = length(unique(.data$grid_id)))
 
   if (all(out$nids==1)) {
-    out <- dplyr::select(out, -.data$grid_id)
+    out <- dplyr::select(out, - "grid_id")
   }
-  out <- dplyr::select(out, -.data$nids)
+  out <- dplyr::select(out, - "nids")
 
   return(out)
 
